
Export and import anime and manga lists on Anime-Planet and MyAnimeList.


Installation and usage
======================

.. code-block:: bash

   pip install ap-mal
   ap-mal --help


Export from Anime-Planet
========================

.. code-block:: bash

   ap-mal -e ap
